@@ -313,8 +313,9 @@ def reconciled(product):
         fup_error = []
         fup_error_name = []
 
+        yesterday = (dt.today() - timedelta(days=1)).strftime("%Y-%m-%d")
         for customer_name in common_customers:
-            fup_history = core.get_last_history(customer_name)
+            fup_history = core.get_history(customer_name, yesterday)
             if fup_history[0]['status']:
                 fup_success.append(fup_history)
                 fup_success_name.append(customer_name)
