@@ -194,7 +194,7 @@ def get_history(customer_name, date):
     """
     Get a given customer's fup history in fup-services database.
     :param customer_name: name of the customer, already lowered
-    :param date: YYYY-mm-dd
+    :param date: str YYYY-mm-dd
     """
     try:
         with records.Database(si_database_url()) as db:
